﻿using System.Text;

using DevExpress.XtraRichEdit.API.Native;

namespace TestProject
{
    /// <summary>
    /// 커스텀 방문자
    /// </summary>
    public class CustomVisitor : DocumentVisitorBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 문자열 빌더
        /// </summary>
        private readonly StringBuilder stringBuilder;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 텍스트 - Text

        /// <summary>
        /// 텍스트
        /// </summary>
        public string Text
        {
            get
            {
                return this.stringBuilder.ToString();
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - CustomVisitor()

        /// <summary>
        /// 생성자
        /// </summary>
        public CustomVisitor()
        {
            this.stringBuilder = new StringBuilder();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 방문하기 - Visit(documentText)

        /// <summary>
        /// 방문하기
        /// </summary>
        /// <param name="documentText">문서 텍스트</param>
        public override void Visit(DocumentText documentText)
        {
            string prefix = (documentText.TextProperties.FontBold) ? "**" : "";

            this.stringBuilder.Append(prefix);
            this.stringBuilder.Append(documentText.Text);
            this.stringBuilder.Append(prefix);
        }

        #endregion
        #region 방문하기 - Visit(documentParagraphEnd)

        /// <summary>
        /// 방문하기
        /// </summary>
        /// <param name="documentParagraphEnd">문서 문단 끝</param>
        public override void Visit(DocumentParagraphEnd documentParagraphEnd)
        {
            this.stringBuilder.AppendLine();
        }

        #endregion
    }
}